Name:          jackson
Version:       1.8.5
Release:       %mkrel 2
Summary:       High-performance JSON processor
Group:         Development/Java 
License:       ASL 2.0, LGPL
Url:           http://jackson.codehaus.org/
Source0:       http://jackson.codehaus.org/1.8.5/jackson-src-1.8.5.tar.gz
Patch0:        jackson-1.8.5-dont-require-repackaged-asm.patch
Patch1:        jackson-1.8.5-javadoc.patch

BuildRequires: jpackage-utils
BuildRequires: java-devel

BuildRequires: ant
BuildRequires: antlr
BuildRequires: bndtask
BuildRequires: cglib
#BuildRequires: cobertura
BuildRequires: glassfish-jaxb-api
BuildRequires: groovy
BuildRequires: guava
BuildRequires: jackson-module-json-org
#BuildRequires: jakarta-oro
#BuildRequires: jarjar
BuildRequires: joda-time
BuildRequires: json
BuildRequires: json_simple
BuildRequires: jsontools
BuildRequires: jsr311
BuildRequires: junit4
#BuildRequires: liblog4j-java
BuildRequires: objectweb-asm

Requires:      jpackage-utils
BuildArch:     noarch

Requires:      cglib
Requires:      groovy
Requires:      java-devel
Requires:      joda-time
Requires:      json


%description
This is the Jackson Json-processor package.

Jackson implements functionality for:

* Reading (parsing) and writing (generation) of Json content
* Data-binding (data-mapping, [de-]serialization) support to
  allow for converting between Json and Java objects
* Support for converting to/from other data formats and access APIs,
  to improve interoperability.

%package javadoc
Group:         Development/Java
Summary:       Javadocs for %{name}
Requires:      jpackage-utils
Requires:      %{name} = %{version}-%{release}

%description javadoc
Jackson - High-performance JSON processor.

This package contains the API documentation for %{name}.

%package samples
Group:         Development/Java 
Summary:       %{name} sample input files
Requires:      %{name} = %{version}-%{release}

%description samples
Jackson - High-performance JSON processor.

This package contains %{name} sample input files.

%prep
%setup -q -n jackson-src-%{version}
%patch0 -p0
%patch1 -p0

find . -name '*.jar' -exec rm -f '{}' \;
find . -name '*.class' -exec rm -f '{}' \;

pushd lib
  pushd ant
#    mv maven-ant-tasks-2.0.10.jar.no maven-ant-tasks-2.0.10.jar
    ln -sf $(build-classpath ant/bndtask) bndtask-0.2.0.jar
  popd
#  pushd cobertura
#    ln -sf $(build-classpath cobertura) cobertura-1.9.4.1.jar
#    ln -sf $(build-classpath objectweb-asm/asm-tree) asm-tree-3.0.jar
#    ln -sf $(build-classpath oro) jakarta-oro-2.0.8.jar
#    ln -sf $(build-classpath log4j) log4j-1.2.13.jar
#  popd
  pushd ext
    ln -sf $(build-classpath joda-time) joda-time-1.5.2.jar
    pushd asm
      ln -sf $(build-classpath objectweb-asm/asm) asm-3.3.jar
    popd
    pushd cglib
      ln -sf $(build-classpath cglib) cglib-nodep-2.2.jar
    popd
    pushd google
      ln -sf $(build-classpath guava) google-collections-1.0.jar
    popd
    pushd groovy
      ln -sf $(build-classpath groovy) groovy-1.7.4.jar
      ln -sf $(build-classpath antlr) antlr-2.7.7.jar
    popd
#    pushd jarjar
#      ln -sf $(build-classpath jarjar) jarjar-1.0.jar
#    popd
  popd
  pushd jaxb
    ln -sf $(build-classpath jaxb-api) jaxb-api-2.0.jar
  popd
  pushd jaxrs
    ln -sf $(build-classpath jsr311) jsr311-api-1.1.jar
# https://svn.java.net/svn/jersey~svn  
#    mv jersey-core-1.1.5.jar jersey-core-1.1.5.jar.no
#    mv jersey-server-1.1.5.jar jersey-server-1.1.5.jar.no
  popd
  pushd junit
    ln -sf $(build-classpath junit4) junit-4.8.2.jar
  popd
  pushd perf
    ln -sf $(build-classpath json) json-org.jar
    ln -sf $(build-classpath jsontools-core) jsontools-core-1.5.jar
    ln -sf $(build-classpath antlr) antlr-2.7.6.jar
    ln -sf $(build-classpath json_simple) json_simple-1.0.2.jar
    ln -sf $(build-classpath jackson/jackson-module-json-org) jackson-module-json-org-0.9.1.jar
  popd
  pushd repackaged
    ln -sf $(build-classpath objectweb-asm/asm) jackson-asm-3.3.jar
  popd
popd

# remove some tests to avoid additional dependencies:
rm src/test/org/codehaus/jackson/map/interop/TestHibernate.java

sed -i "s|<import file="build-maven-deploy.xml" />|<!--import file="build-maven-deploy.xml" /-->|" build.xml

%build

%ant dist

%install

mkdir -p %{buildroot}%{_javadir}/%{name}

mkdir -p %{buildroot}%{_mavenpomdir}
for t in jackson-core-asl \
%{name}-core-lgpl \
%{name}-jaxrs \
%{name}-mapper-asl \
%{name}-mapper-lgpl \
%{name}-mrbean \
%{name}-smile \
%{name}-xc \
; do
  install -m 644 dist/${t}-%{version}.jar %{buildroot}%{_javadir}/%{name}/${t}.jar
  install -m 644 dist/${t}-%{version}.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-${t}.pom
  %add_maven_depmap JPP.%{name}-${t}.pom %{name}/${t}.jar
done
install -m 644 dist/jackson-all-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-all.jar
install -m 644 dist/smile-tool-%{version}.jar %{buildroot}%{_javadir}/%{name}/smile-tool.jar

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr dist/javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

mkdir -p %{buildroot}%{_datadir}/jackson
cp -pr samples %{buildroot}%{_datadir}/jackson/

%files
%{_javadir}/%{name}/%{name}-all.jar
%{_javadir}/%{name}/%{name}-core-asl.jar
%{_javadir}/%{name}/%{name}-core-lgpl.jar
%{_javadir}/%{name}/%{name}-jaxrs.jar
%{_javadir}/%{name}/%{name}-mapper-asl.jar
%{_javadir}/%{name}/%{name}-mapper-lgpl.jar
%{_javadir}/%{name}/%{name}-mrbean.jar
%{_javadir}/%{name}/%{name}-smile.jar
%{_javadir}/%{name}/%{name}-xc.jar
%{_javadir}/%{name}/smile-tool.jar
%{_mavenpomdir}/JPP.%{name}-*.pom
%{_mavendepmapfragdir}/%{name}
%doc README.txt dist/release-notes

%files javadoc
%{_javadocdir}/%{name}

%files samples
%{_datadir}/%{name}


%changelog

* Sat Feb 11 2012 gil <gil> 1.8.5-2.mga2
+ Revision: 207093
- build fix use system objectweb-asm
- update to 1.8.5

* Thu Aug 11 2011 dmorgan <dmorgan> 1.8.4-1.mga2
+ Revision: 132722
- Clean spec file

  + gil <gil>
    - imported package jackson

